@@ -29,6 +29,7 @@ class ManageForm(form.FormBase):
     secondary_actions = form.Actions()
     preview = None
     info = None
+    no_changes = False
     
     def __init__(self, context, request, view):
         self.__parent__ = view
@@ -105,7 +106,8 @@ class ManageForm(form.FormBase):
 
     def update(self):
         request = self.request
-        # for table with listing af all registered adverlets
+
+        # for table with listing of all registered adverlets
         self.adverlets = [i[1] for i in getUtilitiesFor(IAdverlet)]
 
         # preview mode
@@ -134,6 +136,7 @@ class ManageForm(form.FormBase):
         errors, action = form.handleSubmit(
             self.primary_actions, data, self.validate)
 
+        # form result
         if errors:
             self.status = u'There were errors'
             result = action.failure(data, errors)
@@ -145,7 +148,8 @@ class ManageForm(form.FormBase):
 
         self.form_result = result
         
-        if action:
+        # redirect
+        if action and not errors and not self.no_changes:
             custom = request.get('custom')
             
             self.redirect(
@@ -167,6 +171,7 @@ class ManageForm(form.FormBase):
             self.status = _(u'Updated')
         else:
             self.status = _(u'No changes')
+            self.no_changes = True
 
     @form.action(_(u'Close'), secondary_actions)
     def handle_close_action(self, *argv):
