@@ -4,14 +4,19 @@
 
 __license__ = "GPL v.3"
 
-import os
 from zope.component import provideUtility
 from interfaces import IAdverlet
 from adverlet import Adverlet
 
-def registerAdverlet(_context, name, description=None, default=None):
+def registerAdverlet(_context, name, description=None, default=None,
+                     wysiwyg=True):
+
     adverlet = Adverlet()
+
     adverlet.__name__ = name
     adverlet.description = description
     adverlet.default = default
+    adverlet.wysiwyg = wysiwyg
+    adverlet.newlines = not wysiwyg
+
     provideUtility(adverlet, IAdverlet, name=name)
