@@ -6,7 +6,7 @@ __license__ = "GPL v.3"
 __docformat__ = 'restructuredtext'
 
 from zope.interface import Interface
-from zope.schema import TextLine, Text
+from zope.schema import TextLine, Text, Bool
 
 class IAdverletDirective(Interface):
     """ Defines adverlet """
@@ -25,3 +25,9 @@ class IAdverletDirective(Interface):
         title = u'Default view name',
         description = u'Default view name',
         required = False)
+
+    wysiwyg = Bool(
+        title = u'Rich-text editor by default',
+        description = u'Rich-text editor not always useful',
+        required = False,
+        default = True)
