@@ -4,6 +4,7 @@
 
 __license__ = "GPL v.3"
 
+from StringIO import StringIO
 from zope.interface import implements
 from zope.tales.expressions import StringExpr
 from zope.component import queryUtility, getMultiAdapter
@@ -22,7 +23,8 @@ class TALESAdverletExpression(StringExpr):
         source = adverlet.source
 
         if source:
-            return source
+            return not adverlet.newlines and source or ''.join(
+                ['%s <br />' % s for s in StringIO(source).readlines()])
 
         default = adverlet.default
 
